@@ -87,7 +87,10 @@ class Command(BaseCommand):
         APP_SECRET = conf.DROPBOX_APP_SECRET
 
         # ACCESS_TYPE should be 'dropbox' or 'app_folder' as configured for your app
-        ACCESS_TYPE = 'dropbox'
+        try:
+            ACCESS_TYPE = conf.DROPBOX_ACCESS_TYPE
+        except:
+            ACCESS_TYPE = 'dropbox'
 
         # Creating dirs
         dropboxdir = os.path.join(conf.PROJECT_DIR, 'media', 'uploads', 'dropbox')
